@@ -315,6 +315,12 @@ class BundleStream(RestrictedResource):
             raise ValueError("Junk after pathname: %r" % pathname)
         return user, group, slug, is_public, is_anonymous
 
+    def can_upload(self, user):
+        """
+        Return True if the user can upload bundles here
+        """
+        return self.is_anonymous or self.is_owned_by(user)
+
 
 class GzipFileSystemStorage(FileSystemStorage):
 
@@ -650,25 +656,22 @@ class TestCase(models.Model):
         Test,
         related_name='test_cases')
 
-    test_case_id = models.CharField(
+    test_case_id = models.TextField(
         help_text = _help_max_length(100),
-        max_length = 100,
         verbose_name = _("Test case ID"))
 
-    name = models.CharField(
+    name = models.TextField(
         blank = True,
         help_text = _help_max_length(100),
-        max_length = 100,
         verbose_name = _("Name"))
 
-    units = models.CharField(
+    units = models.TextField(
         blank = True,
         help_text = (_("""Units in which measurement value should be
                        interpreted in, for example <q>ms</q>, <q>MB/s</q> etc.
                        There is no semantical meaning inferred from the value of
                        this field, free form text is allowed. <br/>""")
                      + _help_max_length(100)),
-        max_length = 100,
         verbose_name = _("Units"))
 
     class Meta:
